@@ -29,8 +29,14 @@ def cli():
     is_flag=True,
     help="Whether to install dependencies in editable mode",
 )
+@click.option(
+    "-f",
+    "--force",
+    is_flag=True,
+    help="Whether to force reinstall the dependencies",
+)
 @click.option("--cwd", default="", help="Override current working directory")
-def make(package: List[str], editable: bool = False, cwd: str = ""):
+def make(package: List[str], editable: bool = False, force: bool = False, cwd: str = ""):
     """Make package"""
     pbt_cfg = PBTConfig.from_dir(cwd)
     packages = search_packages(pbt_cfg)
@@ -57,7 +63,7 @@ def make(package: List[str], editable: bool = False, cwd: str = ""):
                     # update if there is a change in the dependency make it no longer compatible,
                     if not pkg.is_package_compatible(dep_pkgs[dep_name]):
                         pkg.update_package_version(dep_pkgs[dep_name])
-            if visited_pkgs[dep_name]:
+            if visited_pkgs[dep_name] or force:
                 pkg.install_dep(
                     dep_pkgs[dep_name], pbt_cfg, editable=editable, no_build=True
                 )
