@@ -15,11 +15,6 @@ from pbt.git import Git, GitFileStatus
 if TYPE_CHECKING:
     from pbt.package import Package
 
-try:
-    from functools import cached_property
-except ImportError:
-    from cached_property import cached_property
-
 # file size limit
 SOFT_SIZE_LIMIT = (1024 ** 2) * 1  # 1MB
 HARD_SIZE_LIMIT = (1024 ** 2) * 100  # 100MBs
