@@ -104,7 +104,14 @@ class Package:
                 member = g.getmember(f"{package.name}-{package.version}/setup.py")
                 with open(package.dir / "setup.py", "wb") as f:
                     f.write(g.extractfile(member).read())
-            subprocess.check_call([pipfile, "install", "-e", "."], cwd=package.dir)
+            rename = (package.dir / "pyproject.toml").exists()
+            if rename:
+                os.rename(package.dir / "pyproject.toml", package.dir / "pyproject.toml.tmp")
+            try:
+                subprocess.check_call([pipfile, "install", "-e", "."], cwd=package.dir)
+            finally:
+                if rename:
+                    os.rename(package.dir / "pyproject.toml.tmp", package.dir / "pyproject.toml")
         else:
             subprocess.check_output([pipfile, "install", package.get_wheel_file()])
 
