@@ -11,10 +11,7 @@ from loguru import logger
 if TYPE_CHECKING:
     from pbt.package import Package
 
-try:
-    from functools import cached_property
-except ImportError:
-    from cached_property import cached_property
+from functools import cached_property
 
 
 class Poetry:
